package de.ozgcloud.eingang.enterprise.entry;

import static de.ozgcloud.eingang.enterprise.entry.FormDataMapper.*;

import java.time.LocalDate;
import java.util.List;
import java.util.Map;

public class EntryFormDataTestFactory {

	public static final String FORM_FIELD_NAME = "field_name";
	public static final String FORM_FIELD_VALUE = "field_string_value";
	public static final String FORM_FIELD_LABEL = "field_label";

	public static final String SUB_FORM_NAME = "antragsteller";
	public static final String SUB_FORM_LABEL = "Antragstellende Person";

	public static final String SUB_FORM_STRING_FIELD_NAME = "lastname";
	public static final String SUB_FORM_STRING_FIELD_LABEL = "Nachname";
	public static final String SUB_FORM_STRING_FIELD_VALUE = "Täst";

	public static final String SUB_FORM_NUMBER_FIELD_NAME = "age";
	public static final String SUB_FORM_NUMBER_FIELD_LABEL = "Alter";
	public static final Number SUB_FORM_NUMBER_FIELD_VALUE = 5.5;

	public static final String SUB_FORM_DATE_FIELD_NAME = "birthday";
	public static final String SUB_FORM_DATE_FIELD_LABEL = "Geburtsdatum";
	public static final LocalDate SUB_FORM_DATE_FIELD_VALUE = LocalDate.parse("2017-05-01");

	public static final String SUB_FORM_BOOLEAN_FIELD_NAME = "geprüft";
	public static final String SUB_FORM_BOOLEAN_FIELD_LABEL = "Geprüft";
	public static final Boolean SUB_FORM_BOOLEAN_FIELD_VALUE = true;

	public static List<EntryFormDataItem> create() {
		return List.of(
				EntryFormDataField.builder().name(FORM_FIELD_NAME).label(FORM_FIELD_LABEL).stringValue(FORM_FIELD_VALUE).build(),
				EntryFormDataSubForm.builder().name(SUB_FORM_NAME).label(SUB_FORM_LABEL)
						.formItem(EntryFormDataField.builder()
								.name(SUB_FORM_STRING_FIELD_NAME)
								.label(SUB_FORM_STRING_FIELD_LABEL)
								.stringValue(SUB_FORM_STRING_FIELD_VALUE)
								.build())
						.formItem(EntryFormDataField.builder()
								.name(SUB_FORM_NUMBER_FIELD_NAME)
								.label(SUB_FORM_NUMBER_FIELD_LABEL)
								.numberValue(SUB_FORM_NUMBER_FIELD_VALUE)
								.build())
						.formItem(EntryFormDataField.builder()
								.name(SUB_FORM_DATE_FIELD_NAME)
								.label(SUB_FORM_DATE_FIELD_LABEL)
								.dateValue(SUB_FORM_DATE_FIELD_VALUE)
								.build())
						.formItem(EntryFormDataField.builder()
								.name(SUB_FORM_BOOLEAN_FIELD_NAME)
								.label(SUB_FORM_BOOLEAN_FIELD_LABEL)
								.booleanValue(SUB_FORM_BOOLEAN_FIELD_VALUE)
								.build())
						.build());
	}

	public static Map<String, Object> createAsFormDataMap() {
		return Map.of(
				FORM_FIELD_NAME, Map.of(LABEL_KEY, FORM_FIELD_LABEL, VALUE_KEY, FORM_FIELD_VALUE),
				SUB_FORM_NAME, Map.of(LABEL_KEY, SUB_FORM_LABEL, VALUE_KEY, Map.of(
						SUB_FORM_STRING_FIELD_NAME, Map.of(LABEL_KEY, SUB_FORM_STRING_FIELD_LABEL, VALUE_KEY, SUB_FORM_STRING_FIELD_VALUE),
						SUB_FORM_NUMBER_FIELD_NAME, Map.of(LABEL_KEY, SUB_FORM_NUMBER_FIELD_LABEL, VALUE_KEY, SUB_FORM_NUMBER_FIELD_VALUE),
						SUB_FORM_DATE_FIELD_NAME, Map.of(LABEL_KEY, SUB_FORM_DATE_FIELD_LABEL, VALUE_KEY, SUB_FORM_DATE_FIELD_VALUE),
						SUB_FORM_BOOLEAN_FIELD_NAME, Map.of(LABEL_KEY, SUB_FORM_BOOLEAN_FIELD_LABEL, VALUE_KEY, SUB_FORM_BOOLEAN_FIELD_VALUE))));
	}
}
