/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.intelliform;

public class AttachmentTestFactory {

	public static final String XML_FILE_NAME = "XML-Daten-1.xml";

	public static final String XML_CONTENT_TYPE = "text/xml";
	public static final String XML_CONTENT_STRING = """
			<?xml version="1.0" encoding="UTF-8"?>
			<myForm xmlns:pdf="http://xmlns.cit.de/assistants/pdf"
				xmlns:t="http://xmlns.cit.de/intelliform/transaction"
				t:id="20201118365670866101\" t:timestamp=\"2020-11-18T09:09:27.627Z"
				t:sender="afm.schleswig-holstein.de"
				t:form="Kleiner Waffenschein gem. § 10 Abs. 4 Satz 4 Waffengesetz (WaffG)"
				t:form-id="waffen/kleinerWaffenschein"
				t:customer="Einheitlicher Ansprechpartner" t:customer-id="ea-sh"
				t:client="Schleswig-Holstein"
				t:client-id="land">
				  <Upload1>
				    <file content-type="image/png" description="" id="VendorId3333" length="155251">Image.png</file>
			      </Upload1>
			    </myForm>""";
	public static final byte[] XML_CONTENT = XML_CONTENT_STRING.getBytes();
	public static final String XML_ATTACHMENT_ID = "myForm-xml";
	public static final String XML_NAME = "XML-Daten.xml";

	public static final String PDF_ATTACHMENT_CONTENT_TYPE = "application/pdf";
	public static final byte[] PDF_ATTACHMENT_CONTENT = "TestContent2".getBytes();
	public static final String PDF_ATTACHMENT_NAME = "Scan1.pdf";
	public static final String PDF_ATTACHMENT_ID = "VendorId2222";

	public static final String PNG_ATTACHMENT_CONTENT_TYPE = "application/pdf";
	public static final byte[] PNG_ATTACHMENT_CONTENT = "TestContent3".getBytes();
	public static final String PNG_ATTACHMENT_NAME = "Image.png";
	public static final String PNG_ATTACHMENT_ID = "VendorId3333";

	public static final String ATTRIBUTES_ENTRY_KEY = "X-IntelliForm-Signed";
	public static final String ATTRIBUTES_ENTRY_VALUE = "false";

	public static Attachment createXmlDaten() {
		var attachment = new Attachment();
		attachment.getAttributes().add(createAttributesEntry());
		attachment.setContentType(XML_CONTENT_TYPE);
		attachment.setId(XML_ATTACHMENT_ID);
		attachment.setName(XML_NAME);
		attachment.setContent(XML_CONTENT);
		return attachment;
	}

	public static Attachment createPdf() {
		var attachment = new Attachment();
		attachment.getAttributes().add(createAttributesEntry());
		attachment.setContent(PDF_ATTACHMENT_CONTENT);
		attachment.setContentType(PDF_ATTACHMENT_CONTENT_TYPE);
		attachment.setId(PDF_ATTACHMENT_ID);
		attachment.setName(PDF_ATTACHMENT_NAME);
		return attachment;
	}

	public static Attachment createPng() {
		var attachment = new Attachment();
		attachment.getAttributes().add(createAttributesEntry());
		attachment.setContent(PNG_ATTACHMENT_CONTENT);
		attachment.setContentType(PNG_ATTACHMENT_CONTENT_TYPE);
		attachment.setId(PNG_ATTACHMENT_ID);
		attachment.setName(PNG_ATTACHMENT_NAME);
		return attachment;
	}

	private static Entry createAttributesEntry() {
		var attributesEntry = new Entry();
		attributesEntry.setKey(ATTRIBUTES_ENTRY_KEY);
		attributesEntry.setValue(ATTRIBUTES_ENTRY_VALUE);
		return attributesEntry;
	}
}
