/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.semantik.enginebased.formsolutions;

import static de.ozgcloud.eingang.semantik.enginebased.formsolutions.FormSolutionsEngineBasedAdapter.*;

import java.util.Map;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import de.ozgcloud.eingang.common.formdata.FormData;
import de.ozgcloud.eingang.common.formdata.FormDataUtils;
import de.ozgcloud.eingang.common.formdata.FormHeader;
import de.ozgcloud.eingang.semantik.enginebased.ServiceKontoBuildHelper;

@Component
class FormSolutionsHeaderMapper implements FormSolutionsEngineBasedMapper {

	static final int POSTFACH_ADDRESS_DEFAULT = 1;

	static final String TRANSACTION_ID = "transactionId";

	static final String FORM_ENGINE_NAME = "FormSolutions";

	public static final String POSTKORBHANDLE = "postkorbhandle";

	@Autowired
	private ServiceKontoBuildHelper serviceKontoBuildHelper;

	@Override
	public FormData parseFormData(FormData formData) {
		return FormDataUtils.from(formData)
				.remove(TRANSACTION_ID)
				.builder()
				.header(buildFormHeader(formData))
				.build();
	}

	protected FormHeader buildFormHeader(FormData formData) {
		var formHeaderBuilder = FormHeader.builder()
				.formName(getIdentifier(formData))
				.formId(getIdentifier(formData))
				.requestId(getRequestId(formData))
				.formEngineName(FORM_ENGINE_NAME);

		Optional.ofNullable(getPostkorbhandle(formData)).map(serviceKontoBuildHelper::buildOsiServiceKonto).ifPresent(formHeaderBuilder::serviceKonto);

		return formHeaderBuilder.build();
	}

	private String getIdentifier(FormData formData) {
		return (String) getAssistant(formData).get(IDENTIFIER_KEY);
	}

	private Map<String, Object> getAssistant(FormData formData) {
		return FormDataUtils.getSubMap(formData, ASSISTANT);
	}

	private String getRequestId(FormData formData) {
		return (String) formData.getFormData().get(TRANSACTION_ID);
	}

	private String getPostkorbhandle(FormData formData) {
		return (String) formData.getFormData().get(POSTKORBHANDLE);
	}
}