package de.ozgcloud.eingang.xta;

import java.math.BigInteger;
import java.net.URI;

import jakarta.validation.constraints.NotEmpty;
import jakarta.validation.constraints.NotNull;

import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.io.Resource;
import org.springframework.stereotype.Component;
import org.springframework.validation.annotation.Validated;

import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

@Validated
@ToString
@Setter
@Getter
@Configuration
@ConfigurationProperties(prefix = XtaProperties.PROPERTIES_PREFIX)
class XtaProperties {
	static final String PROPERTIES_PREFIX = "ozgcloud.xta";

	private Server server;
	private BigInteger maxListElements;

	private KeyStore keyStore;
	private Actions actions;
	@NotEmpty
	private String identifier;
}

@Validated
@ToString
@Getter
@Setter
@Component
@ConfigurationProperties(prefix = Server.PROPERTIES_PREFIX)
class Server {
	static final String PROPERTIES_PREFIX = XtaProperties.PROPERTIES_PREFIX + ".server";

	@NotEmpty
	private String name;
	private String address;
	@NotEmpty
	private String protocol;
}

@Validated
@ToString
@Getter
@Setter
@Component
@ConfigurationProperties(prefix = KeyStore.PROPERTIES_PREFIX)
class KeyStore {
	static final String PROPERTIES_PREFIX = XtaProperties.PROPERTIES_PREFIX + ".keystore";

	@NotNull
	private Resource file;
	private String type = "PKCS12";
	@NotEmpty
	private char[] password;
}

@Validated
@ToString
@Setter
@Getter
@Configuration
@ConfigurationProperties(prefix = Actions.PROPERTIES_PREFIX)
class Actions {
	static final String PROPERTIES_PREFIX = XtaProperties.PROPERTIES_PREFIX + ".actions";

	@NotNull
	private URI statusList;
	@NotNull
	private URI fetchRequest;
	@NotNull
	private URI closeRequest;
}
